# Sentimatrix Test Summary

**Date:** 2026-01-28 09:30:45
**Status:** FAILED
**Return Code:** 1

## Test Configuration

- Python Version: 3.10.12 (main, Jun 11 2023, 05:26:28) [GCC 11.4.0]
- Test Framework: pytest

## Results

See `test_results_20260128_093035.xml` for detailed JUnit XML results.

## Coverage

If coverage was enabled, see `coverage_html/index.html` for detailed coverage report.

---
*Generated by Sentimatrix Test Runner*
